@@ -170,8 +170,8 @@ def from_conf(conf, session=None, **kwargs):
                       "for project '{project}' (service type "
                       "'{service_type}'): {exception}".format(
                           project=project_name, service_type=st, exception=e))
-            _logger.warn("Disabling service '{service_type}': {reason}".format(
-                service_type=st, reason=reason))
+            _logger.warning("Disabling service '{service_type}': "
+                            "{reason}".format(service_type=st, reason=reason))
             _disable_service(config_dict, st, reason=reason)
             continue
         # Load them into config_dict under keys prefixed by ${service_type}_
@@ -451,6 +451,14 @@ class CloudRegion(object):
             value = auth.get('auth_url')
         return value
 
+    def get_endpoint_from_catalog(self, service_type):
+        session = self.get_session()
+        return session.auth.get_endpoint(
+            session,
+            service_type=service_type,
+            region_name=self.get_region_name(service_type),
+            interface=self.get_interface(service_type))
+
     def get_connect_retries(self, service_type):
         return self._get_config('connect_retries', service_type,
                                 fallback_to_unprefixed=True,
